@@ -2,8 +2,12 @@ mod extract_word_docids;
 mod extract_word_pair_proximity_docids;
 mod tokenize_document;
 
-pub use extract_word_docids::{WordDocidsCaches, WordDocidsExtractors};
-pub use extract_word_pair_proximity_docids::WordPairProximityDocidsExtractor;
+pub use extract_word_docids::{
+    SettingsChangeWordDocidsExtractors, WordDocidsCaches, WordDocidsExtractors,
+};
+pub use extract_word_pair_proximity_docids::{
+    SettingsChangeWordPairProximityDocidsExtractors, WordPairProximityDocidsExtractor,
+};
 
 use crate::attribute_patterns::{match_field_legacy, PatternMatch};
 
@@ -27,3 +31,17 @@ pub fn match_searchable_field(
 
     selection
 }
+
+/// return `true` if the provided `field_name` is a parent of at least one of the fields contained in `searchable`,
+/// or if `searchable` is `None`.
+fn has_searchable_children<I, A>(field_name: &str, searchable: Option<I>) -> bool
+where
+    I: IntoIterator<Item = A>,
+    A: AsRef<str>,
+{
+    searchable.is_none_or(|fields| {
+        fields
+            .into_iter()
+            .any(|attr| match_field_legacy(attr.as_ref(), field_name) == PatternMatch::Parent)
+    })
+}
