@@ -1,5 +1,6 @@
 use std::cell::RefCell;
 use std::fmt::Debug;
+use std::sync::RwLock;
 
 use bumpalo::collections::Vec as BVec;
 use bumpalo::Bump;
@@ -27,7 +28,10 @@ use crate::vector::extractor::{
 use crate::vector::session::{EmbedSession, Input, Metadata, OnEmbed};
 use crate::vector::settings::ReindexAction;
 use crate::vector::{Embedding, RuntimeEmbedder, RuntimeEmbedders, RuntimeFragment};
-use crate::{DocumentId, FieldDistribution, InternalError, Result, ThreadPoolNoAbort, UserError};
+use crate::{
+    DocumentId, FieldDistribution, GlobalFieldsIdsMap, InternalError, Result, ThreadPoolNoAbort,
+    UserError,
+};
 
 pub struct EmbeddingExtractor<'a, 'b> {
     embedders: &'a RuntimeEmbedders,
@@ -321,6 +325,15 @@ impl<'extractor, SD: SettingsDelta + Sync> SettingsChangeExtractor<'extractor>
         let old_embedders = self.settings_delta.old_embedders();
         let unused_vectors_distribution = UnusedVectorsDistributionBump::new_in(&context.doc_alloc);
 
+        // We get a reference to the new and old fields ids maps but
+        // note that those are local versions where updates to them
+        // will not be reflected in the database. It's not an issue
+        // because new settings do not generate new fields.
+        let new_fields_ids_map = RwLock::new(self.settings_delta.new_fields_ids_map().clone());
+        let new_fields_ids_map = RefCell::new(GlobalFieldsIdsMap::new(&new_fields_ids_map));
+        let old_fields_ids_map = RwLock::new(self.settings_delta.old_fields_ids_map().clone());
+        let old_fields_ids_map = RefCell::new(GlobalFieldsIdsMap::new(&old_fields_ids_map));
+
         let mut all_chunks = BVec::with_capacity_in(embedders.len(), &context.doc_alloc);
         let embedder_configs = context.index.embedding_configs();
         for (embedder_name, action) in self.settings_delta.embedder_actions().iter() {
@@ -396,6 +409,7 @@ impl<'extractor, SD: SettingsDelta + Sync> SettingsChangeExtractor<'extractor>
                         if !must_regenerate {
                             continue;
                         }
+
                         // we need to regenerate the prompts for the document
                         chunks.settings_change_autogenerated(
                             document.docid(),
@@ -406,7 +420,8 @@ impl<'extractor, SD: SettingsDelta + Sync> SettingsChangeExtractor<'extractor>
                                 context.db_fields_ids_map,
                             )?,
                             self.settings_delta,
-                            context.new_fields_ids_map,
+                            &old_fields_ids_map,
+                            &new_fields_ids_map,
                             &unused_vectors_distribution,
                             old_is_user_provided,
                             fragments_changed,
@@ -442,7 +457,8 @@ impl<'extractor, SD: SettingsDelta + Sync> SettingsChangeExtractor<'extractor>
                                     context.db_fields_ids_map,
                                 )?,
                                 self.settings_delta,
-                                context.new_fields_ids_map,
+                                &old_fields_ids_map,
+                                &new_fields_ids_map,
                                 &unused_vectors_distribution,
                                 old_is_user_provided,
                                 true,
@@ -638,7 +654,8 @@ impl<'a, 'b, 'extractor> Chunks<'a, 'b, 'extractor> {
         external_docid: &'a str,
         document: D,
         settings_delta: &SD,
-        fields_ids_map: &'a RefCell<crate::GlobalFieldsIdsMap>,
+        old_fields_ids_map: &'a RefCell<GlobalFieldsIdsMap<'a>>,
+        new_fields_ids_map: &'a RefCell<GlobalFieldsIdsMap<'a>>,
         unused_vectors_distribution: &UnusedVectorsDistributionBump<'a>,
         old_is_user_provided: bool,
         full_reindex: bool,
@@ -733,10 +750,17 @@ impl<'a, 'b, 'extractor> Chunks<'a, 'b, 'extractor> {
                     old_embedder.as_ref().map(|old_embedder| &old_embedder.document_template)
                 };
 
-                let extractor =
-                    DocumentTemplateExtractor::new(document_template, doc_alloc, fields_ids_map);
+                let extractor = DocumentTemplateExtractor::new(
+                    document_template,
+                    doc_alloc,
+                    new_fields_ids_map,
+                );
                 let old_extractor = old_document_template.map(|old_document_template| {
-                    DocumentTemplateExtractor::new(old_document_template, doc_alloc, fields_ids_map)
+                    DocumentTemplateExtractor::new(
+                        old_document_template,
+                        doc_alloc,
+                        old_fields_ids_map,
+                    )
                 });
                 let metadata =
                     Metadata { docid, external_docid, extractor_id: extractor.extractor_id() };
