@@ -28,6 +28,9 @@ make_enum_progress! {
         ChangingVectorStore,
         UsingStableIndexer,
         UsingExperimentalIndexer,
+        DeletingOldWordFidDocids,
+        DeletingOldFidWordCountDocids,
+        DeletingOldWordPrefixFidDocids,
     }
 }
 
